==> icons-vue-0.6.0.tgz: package/es/enterprise/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_Enterprise20 = {
  name: 'Enterprise20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4",
        "x": "8",
        "y": "8"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4",
        "x": "8",
        "y": "14"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4",
        "x": "14",
        "y": "8"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4",
        "x": "14",
        "y": "14"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4",
        "x": "8",
        "y": "20"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4",
        "x": "14",
        "y": "20"
      }
    }), createElement('path', {
      attrs: {
        "d": "M30,14a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30ZM4,4H20V28H4ZM22,28V14h6V28Z"
      }
    }), children]);
  }
};

export default virtual_Enterprise20;

==> icons-vue-10.6.1.tgz: package/es/enterprise/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@carbon/icon-helpers';

var virtual_Enterprise20 = {
  name: 'Enterprise20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M28 28V14a2 2 0 0 0-2-2h-4V4a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v24H2v2h28v-2zM6 4h14v24H6zm16 24V14h4v14z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M10 8h2v4h-2zm0 6h2v4h-2zm4-6h2v4h-2zm0 6h2v4h-2zm-4 6h2v4h-2zm4 0h2v4h-2z"
      }
    }), children]);
  }
};

export default virtual_Enterprise20;
